pub enum Error {
HeaderNotFound,
Io(Error),
BinRw(Error),
InvalidCharacter,
UnexpectedEof,
UnsupportedSeek,
}Expand description
General error used by the crate
Variants
HeaderNotFound
The BinHex 4.0 header could not be located
Io(Error)
A read or seek operation on the underlying reader failed
BinRw(Error)
Some data could not be decoded from the underlying reader
InvalidCharacter
The binhex encoded stream contains unknown characters
UnexpectedEof
The underlying stream did not provide enough data for decompression
UnsupportedSeek
The seek operation is not supported