Archive

Struct Archive 

pub struct Archive<R> { /* private fields */ }
Reader for BinHex archives

Implementations

Source

impl<R> Archive<R>

pub fn name(&self) -> &str

Original name of the embedded file

pub fn file_code(&self) -> FourCC

The file’s four-byte type identifier

pub fn creator_code(&self) -> FourCC

The file’s four-byte creator code

pub fn finder_flags(&self) -> FinderFlags

Finder flags at the time of compression

pub fn data_len(&self) -> usize

Number of bytes in the uncompressed data fork

pub fn resource_len(&self) -> usize

Number of bytes in the uncompressed resource fork

pub fn header_checksum(&self) -> u16

CRC-16 checksum of the header bytes

The CRC-16 configuration is CRC-16-XMODEM the CRC of ASCII “123456789” is 0x31C3.

Source

impl<R: Read + Seek> Archive<R>

pub const HEADER: &[u8; 45] = b"(This file must be converted with BinHex 4.0)"

Fixed header that introduces the start of encoded data

pub fn try_from(inner: R) -> Result<Self, Error>

Try to read an archive from the reader.

It searches for the start marker and reads the archive header after that. Returns an error if either fails.

pub fn data_fork( &mut self, ) -> Result<ForkReader<&mut SixBitRleReader<R>>, Error>

Open the data fork for reading

Since reading backwards through RLE encoded data is expensive, this should be called before accessing the resource fork, if the application wants to read both

pub fn resource_fork( &mut self, ) -> Result<ForkReader<&mut SixBitRleReader<R>>, Error>

Open the resource fork for reading

Since reading backwards through RLE encoded data is expensive, this should be called after accessing the data fork, if the application wants to read both

pub fn verify(&mut self) -> Result<(), VerificationError>

Verify checksums of the whole archive, this resets the stream and reads the whole file to calculate the checksums.

pub fn into_inner(self) -> R

Returns the underlying reader that was used initially to open the archive Note that the read position has probably changed

Source

impl Archive<File>

pub fn open<P: AsRef<Path>>(path: P) -> Result<Self, Error>

Try to open the archive specified by path

pub fn try_clone(&self) -> Result<Self>

Try to clone the archive which would allow you to read resource and data forks simultaneously