pub struct ArchiveHeader {
pub name: String,
pub file_code: FourCC,
pub creator_code: FourCC,
pub finder_flags: FinderFlags,
pub data_len: u32,
pub resource_len: u32,
pub header_checksum: u16,
}Expand description
On-disk structure describing contents of the BinHex archive
Fields
name: StringOriginal name of the embedded file
file_code: FourCCFour-byte type code for the embedded file
creator_code: FourCCFour-byte identifier for the program that created the file
finder_flags: FinderFlagsFinder flags as observed at the time of compression
data_len: u32Number of bytes in the uncompressed data fork
resource_len: u32Number of bytes in the uncompressed resource fork
header_checksum: u16CRC-16 checksum of the header bytes
The CRC-16 configuration is CRC-16-XMODEM the CRC of ASCII “123456789” is 0x31C3.
Implementations
Sourceimpl ArchiveHeader
impl ArchiveHeader
Sourcepub const FIXED_SIZE: usize = 22
pub const FIXED_SIZE: usize = 22
Fixed size of the header on disk